@@ -313,5 +313,5 @@ def get_function_definitions_list(function_signatures):
 
     definition_list = []
     for signature in function_signatures:
-        definition_list.append(SyntaxWarning(signature))
+        definition_list.append(signature_to_function(signature))
     return definition_list
\ No newline at end of file
